@@ -5,7 +5,8 @@ use strict;
 use warnings;
 use Carp qw(confess);
 use File::Find;
-use File::Basename;
+use File::Spec;
+use Config;
 
 use Jenkins::i18n::Properties;
 
@@ -33,7 +34,7 @@ our @EXPORT_OK = (
     'load_jelly'
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head2 EXPORT
 
@@ -133,20 +134,43 @@ Returns an sorted array reference with the complete path to those files.
 
 =cut
 
+# Relative paths inside the Jenkins project repository
+my $src_test_path = File::Spec->catfile( 'src',    'test' );
+my $target_path   = File::Spec->catfile( 'target', '' );
+my $src_regex     = qr/$src_test_path/;
+my $target_regex  = qr/$target_path/;
+my $msgs_regex    = qr/Messages\.properties$/;
+my $jelly_regex   = qr/\.jelly$/;
+
+my $win_sep_regex;
+
+if ( $Config{osname} eq 'MSWin32' ) {
+    $win_sep_regex = qr#/#;
+}
+
 sub find_files {
     my $dir = shift;
-    confess "Must provide a string, invalid directory parameter"
+    die "Must provide a string, invalid directory parameter"
         unless ($dir);
-    confess "Must provide a string, invalid directory parameter"
+    die "Must provide a string, invalid directory parameter"
         unless ( ref($dir) eq '' );
-    confess "Directory $dir must exists" unless ( -d $dir );
+    die "Directory $dir must exists" unless ( -d $dir );
     my @files;
+
+    # BUGFIX: File::Find::name is not returning with MS Windows separator
+    my $is_windows = 0;
+    $is_windows = 1 if ( $Config{osname} eq 'MSWin32' );
+
     find(
         sub {
             my $file = $File::Find::name;
-            push( @files, $file )
-                if ( $file !~ m#(/src/test/)|(/target/)#
-                && $file =~ /(Messages.properties)$|(.*\.jelly)$/ );
+            $file =~ s#$win_sep_regex#\\# if ($is_windows);
+
+            unless ( ( $file =~ $src_regex ) or ( $file =~ $target_regex ) ) {
+                push( @files, $file )
+                    if ( ( $file =~ $msgs_regex )
+                    or ( $file =~ $jelly_regex ) );
+            }
         },
         $dir
     );
